# ifndef yyInitAllocate
# define yyInitAllocate

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* InitAllocate_Exit) ARGS ((void));

extern void InitAllocate ARGS ((tTree t, tTree unit));

extern void BeginInitAllocate ARGS ((void));
extern void CloseInitAllocate ARGS ((void));

# endif
